import { createOrUpdateFile } from "../sync/update.js";
import { getLints } from "../lint/getLints.js";
import { getAutocompletion } from "../autocomplete/getAutocompletion.js";
import { getHover } from "../hover/getHover.js";
/**
 * Create a worker with `WorkerShape`, given an initializer
 * method. You might want to customize how your TypeScript
 * environment is set up, so the initializer can do all
 * of that: this then gives you an object that can be
 * passed to `Comlink.expose`.
 */
export function createWorker(initializer) {
    let env;
    return {
        async initialize() {
            env = await initializer();
        },
        updateFile({ path, code }) {
            if (!env)
                return;
            createOrUpdateFile(env, path, code);
        },
        getLints({ path }) {
            if (!env)
                return [];
            return getLints({ env, path });
        },
        getAutocompletion({ path, context, }) {
            if (!env)
                return null;
            return getAutocompletion({ env, path, context });
        },
        getHover({ path, pos }) {
            if (!env)
                return;
            return getHover({ env, path, pos });
        },
    };
}
//# sourceMappingURL=createWorker.js.map